@@ -61,18 +61,25 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 http://www.gnu.org/copyleft/gpl.html
 """
 
-import os, math, struct, stat, hashlib
+import hashlib
+import math
+import os
+import stat
+import struct
 
 import Cryptodome.Random as Random
 from Cryptodome.Cipher import AES
 from . import PBKDFv2, AfSplitter
 
+
 class LuksError(Exception):
     def __init__(self, value):
         self.value = value
+
     def __str__(self):
         return repr(self.value)
 
+
 class LuksFile:
     """Implements the LUKS (Linux Unified Key Setup) Version 1.0 http://luks.endorphin.org/"""
 
@@ -109,17 +116,17 @@ class LuksFile:
         self.file.seek(0)
 
         self.magic, \
-        self.version, \
-        cipherName, \
-        cipherMode, \
-        hashSpec, \
-        self.payloadOffset, \
-        self.keyBytes, \
-        self.mkDigest, \
-        self.mkDigestSalt, \
-        self.mkDigestIterations, \
-        self.uuid = \
-        struct.unpack(self.LUKS_FORMAT, self.file.read(208))
+            self.version, \
+            cipherName, \
+            cipherMode, \
+            hashSpec, \
+            self.payloadOffset, \
+            self.keyBytes, \
+            self.mkDigest, \
+            self.mkDigestSalt, \
+            self.mkDigestIterations, \
+            self.uuid = \
+            struct.unpack(self.LUKS_FORMAT, self.file.read(208))
 
         cipherName = cipherName.decode()
         cipherMode = cipherMode.decode()
@@ -258,7 +265,8 @@ class LuksFile:
         if key.active != self.LUKS_KEY_DISABLED:
             raise LuksError("Key is active.  Delete the key and try again")
 
-        if checkMinStripes == 0: checkMinStripes = self.KEY_STRIPES
+        if checkMinStripes == 0:
+            checkMinStripes = self.KEY_STRIPES
         if key.stripes < checkMinStripes:
             raise LuksError("Key section %i contains too few stripes.  Header manipulation?" % keyIndex)
 
@@ -286,7 +294,7 @@ class LuksFile:
         AfSectors = int(math.ceil(float(AfKeySize) / self.SECTOR_SIZE))
         for sector in range(0, AfSectors):
             self._encrypt_sector(derived_key, key.keyMaterialOffset + sector, sector, \
-                   AfKey[int(sector*self.SECTOR_SIZE):int((sector+1)*self.SECTOR_SIZE)])
+                                 AfKey[int(sector*self.SECTOR_SIZE):int((sector+1)*self.SECTOR_SIZE)])
 
         key.active = self.LUKS_KEY_ENABLED
 
@@ -341,7 +349,6 @@ class LuksFile:
         self.ivGen.set_key(self.masterKey)
         return True
 
-
     def open_any_key(self, password):
         """Try to open any enabled key using the provided password.  Returns index number on success, or None"""
 
@@ -513,23 +520,23 @@ class LuksFile:
 
         return ret[frontPad:frontPad+length]
 
-    ##### Private functions
+    # Private functions
 
     class _key_block:
         """Internal class, used to store the key information about each key."""
 
         LUKS_KEY_FORMAT = ">II32sII"
 
-        def load_from_str(self,str):
+        def load_from_str(self, str):
             """Unpack the key information from a string"""
             self.active, \
-            self.passwordIterations, \
-            self.passwordSalt, \
-            self.keyMaterialOffset, \
-            self.stripes =  \
-            struct.unpack(self.LUKS_KEY_FORMAT,str)
+                self.passwordIterations, \
+                self.passwordSalt, \
+                self.keyMaterialOffset, \
+                self.stripes =  \
+                struct.unpack(self.LUKS_KEY_FORMAT, str)
 
-        def create(self,offset, stripes, disabled):
+        def create(self, offset, stripes, disabled):
             """Create a new set of key information.  Called from LuksFile.create()"""
             self.active = disabled
             self.passwordIterations = 0
@@ -540,7 +547,7 @@ class LuksFile:
         def save(self):
             """Pack the key information into a string"""
             return struct.pack(self.LUKS_KEY_FORMAT, self.active, self.passwordIterations, \
-                    self.passwordSalt, self.keyMaterialOffset, self.stripes)
+                               self.passwordSalt, self.keyMaterialOffset, self.stripes)
 
     class _plain_iv_gen:
         """Internal class to represent cbc-plain cipherMode"""
@@ -603,17 +610,17 @@ class LuksFile:
         # by Denys Duchier http://ofxsuite.berlios.de/uuid.py  (which is under the GPL)
 
         buf = rand.read(16)
-        low,mid,hi_and_version,seq,node = struct.unpack(">IHHH6s",buf)
+        low, mid, hi_and_version, seq, node = struct.unpack(">IHHH6s", buf)
         seq = (seq & 0x3FFF) | 0x8000
         hi_and_version = (hi_and_version & 0x0FFF) | 0x4000
-        uuid = struct.pack(">IHHH6s",low,mid,hi_and_version,seq,node)
-        low,mid,hi,seq,b5,b4,b3,b2,b1,b0 = struct.unpack(">IHHHBBBBBB",uuid)
-        self.uuid =  b"%08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x" % (low,mid,hi,seq>>8,seq&0xFF,b5,b4,b3,b2,b1,b0)
+        uuid = struct.pack(">IHHH6s", low, mid, hi_and_version, seq, node)
+        low, mid, hi, seq, b5, b4, b3, b2, b1, b0 = struct.unpack(">IHHHBBBBBB", uuid)
+        self.uuid = b"%08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x" % (low, mid, hi, seq >> 8, seq & 0xFF, b5, b4, b3, b2, b1, b0)
 
     def _save_header(self):
         """Internal function to save the header info into the file"""
-        str=struct.pack(self.LUKS_FORMAT, self.magic, self.version, self.cipherName.encode(), self.cipherMode.encode(), self.hashSpec.encode(), \
-             self.payloadOffset, self.keyBytes, self.mkDigest, self.mkDigestSalt, self.mkDigestIterations, self.uuid)
+        str = struct.pack(self.LUKS_FORMAT, self.magic, self.version, self.cipherName.encode(), self.cipherMode.encode(), self.hashSpec.encode(), \
+                          self.payloadOffset, self.keyBytes, self.mkDigest, self.mkDigestSalt, self.mkDigestIterations, self.uuid)
         self.file.seek(0)
         self.file.write(str)
 
@@ -657,19 +664,19 @@ class LuksFile:
 # The following was copied from the reference implementation of LUKS in cryptsetup-luks-1.0.1 from
 # http://luks.endorphin.org/dm-crypt
 
-#define LUKS_CIPHERNAME_L 32
-#define LUKS_CIPHERMODE_L 32
-#define LUKS_HASHSPEC_L 32
-#define LUKS_DIGESTSIZE 20 // since SHA1
-#define LUKS_HMACSIZE 32
-#define LUKS_SALTSIZE 32
-#define LUKS_NUMKEYS 8
-#define LUKS_MAGIC_L 6
+# define LUKS_CIPHERNAME_L 32
+# define LUKS_CIPHERMODE_L 32
+# define LUKS_HASHSPEC_L 32
+# define LUKS_DIGESTSIZE 20 // since SHA1
+# define LUKS_HMACSIZE 32
+# define LUKS_SALTSIZE 32
+# define LUKS_NUMKEYS 8
+# define LUKS_MAGIC_L 6
 
-#/* Actually we need only 37, but we don't want struct autoaligning to kick in */
-#define UUID_STRING_L 40
+# /* Actually we need only 37, but we don't want struct autoaligning to kick in */
+# define UUID_STRING_L 40
 
-#struct luks_phdr {
+# struct luks_phdr {
 #   char        magic[LUKS_MAGIC_L];
 #   uint16_t    version;
 #   char        cipherName[LUKS_CIPHERNAME_L];
@@ -693,6 +700,6 @@ class LuksFile:
 #       uint32_t keyMaterialOffset;
 #       uint32_t stripes;
 #   } keyblock[LUKS_NUMKEYS];
-#};
+# };
 
 # size is 208 bytes + 48 * LUKS_NUMKEYS  = 592 bytes
