@@ -26,7 +26,9 @@
 from . import base
 from revelation import data, entry
 
-import locale, re, struct
+import locale
+import re
+import struct
 from Cryptodome.Cipher import Blowfish
 import Cryptodome.Random as Random
 
@@ -41,7 +43,6 @@ FIELDTYPE_PASSWORD  = 0x06
 FIELDTYPE_END       = 0xff
 
 
-
 # We need our own SHA1-implementation, because Password Safe does
 # non-standard things we need to replicate. This implementation is
 # written by J. Hallen and L. Creighton for the Pypy project, with
@@ -55,7 +56,6 @@ class SHA:
         0xCA62C1D6
     ]
 
-
     def __init__(self, input = None):
         self.count = [0, 0]
         self.init()
@@ -63,7 +63,6 @@ class SHA:
         if input != None:
             self.update(input)
 
-
     def __bytelist2longBigEndian(self, list):
         imax = len(list)//4
         hl = [0] * imax
@@ -81,7 +80,6 @@ class SHA:
 
         return hl
 
-
     def __long2bytesBigEndian(self, n, blocksize=0):
         s = b''
         pack = struct.pack
@@ -103,11 +101,9 @@ class SHA:
 
         return s
 
-
     def __rotateLeft(self, x, n):
         return (x << n) | (x >> (32-n))
 
-
     def __transform(self, W):
         for t in range(16, 80):
             W.append(self.__rotateLeft(
@@ -151,14 +147,12 @@ class SHA:
             B = A
             A = TEMP & 0xffffffff
 
-
         self.H0 = (self.H0 + A) & 0xffffffff
         self.H1 = (self.H1 + B) & 0xffffffff
         self.H2 = (self.H2 + C) & 0xffffffff
         self.H3 = (self.H3 + D) & 0xffffffff
         self.H4 = (self.H4 + E) & 0xffffffff
 
-
     def digest(self):
         H0 = self.H0
         H1 = self.H1
@@ -182,10 +176,10 @@ class SHA:
         self.__transform(bits)
 
         digest = self.__long2bytesBigEndian(self.H0, 4) + \
-                self.__long2bytesBigEndian(self.H1, 4) + \
-                self.__long2bytesBigEndian(self.H2, 4) + \
-                self.__long2bytesBigEndian(self.H3, 4) + \
-                self.__long2bytesBigEndian(self.H4, 4)
+            self.__long2bytesBigEndian(self.H1, 4) + \
+            self.__long2bytesBigEndian(self.H2, 4) + \
+            self.__long2bytesBigEndian(self.H3, 4) + \
+            self.__long2bytesBigEndian(self.H4, 4)
 
         self.H0 = H0
         self.H1 = H1
@@ -197,11 +191,9 @@ class SHA:
 
         return digest
 
-
     def hexdigest(self):
         return ''.join(['%02x' % ord(c) for c in self.digest()])
 
-
     def init(self, H0 = 0x67452301, H1 = 0xEFCDAB89, H2 = 0x98BADCFE, H3 = 0x10325476, H4 = 0xC3D2E1F0):
         self.length = 0
         self.input = []
@@ -212,7 +204,6 @@ class SHA:
         self.H3 = H3
         self.H4 = H4
 
-
     def update(self, inBuf):
         leninBuf = len(inBuf)
 
@@ -246,16 +237,16 @@ def decrypt(key, ciphertext, iv = None):
     if len(ciphertext) % 8 != 0:
         raise base.FormatError
 
-    cipher      = Blowfish.new(key, Blowfish.MODE_ECB)
+    cipher      = Blowfish.new(key, Blowfish.MODE_ECB)  # nosec
     cbc     = iv
     plaintext   = b""
 
-    for cipherblock in [ ciphertext[i * 8 : (i + 1) * 8] for i in range(len(ciphertext) // 8) ]:
+    for cipherblock in [ciphertext[i * 8: (i + 1) * 8] for i in range(len(ciphertext) // 8)]:
 
         plainblock = decrypt_block(cipher, cipherblock)
 
         if cbc != None:
-            plainblock = bytes([ plainblock[i] ^ cbc[i] for i in range(len(plainblock)) ])
+            plainblock = bytes([plainblock[i] ^ cbc[i] for i in range(len(plainblock))])
             cbc = cipherblock
 
         plaintext += plainblock
@@ -279,14 +270,14 @@ def encrypt(key, plaintext, iv = None):
     if len(plaintext) % 8 != 0:
         raise base.FormatError
 
-    cipher      = Blowfish.new(key, Blowfish.MODE_ECB)
+    cipher      = Blowfish.new(key, Blowfish.MODE_ECB)  # nosec
     cbc     = iv
     ciphertext  = b""
 
-    for plainblock in [ plaintext[i * 8 : (i + 1) * 8] for i in range(len(plaintext) // 8) ]:
+    for plainblock in [plaintext[i * 8: (i + 1) * 8] for i in range(len(plaintext) // 8)]:
 
         if cbc != None:
-            plainblock = bytes([ plainblock[i] ^ cbc[i] for i in range(len(plainblock)) ])
+            plainblock = bytes([plainblock[i] ^ cbc[i] for i in range(len(plainblock))])
 
         cipherblock = encrypt_block(cipher, plainblock)
         ciphertext += cipherblock
@@ -294,7 +285,6 @@ def encrypt(key, plaintext, iv = None):
         if cbc != None:
             cbc = cipherblock
 
-
     return ciphertext
 
 
@@ -312,7 +302,7 @@ def generate_testhash(password, random):
     "Generates a testhash based on a password and a random string"
 
     key = SHA(random + b"\x00\x00" + password.encode()).digest()
-    cipher  = Blowfish.new(key, Blowfish.MODE_ECB)
+    cipher  = Blowfish.new(key, Blowfish.MODE_ECB)  # nosec
 
     for i in range(1000):
         random = encrypt_block(cipher, random)
@@ -326,7 +316,6 @@ def generate_testhash(password, random):
     return testhash
 
 
-
 def create_field(value, type = FIELDTYPE_NAME):
     "Creates a field"
     if isinstance(value, str):
@@ -367,7 +356,6 @@ def parse_field_header(header):
     return length, type
 
 
-
 class PasswordSafe1(base.DataHandler):
     "Data handler for PasswordSafe 1.x data"
 
@@ -376,11 +364,9 @@ class PasswordSafe1(base.DataHandler):
     exporter    = True
     encryption  = True
 
-
     def __init__(self):
         base.DataHandler.__init__(self)
 
-
     def check(self, input):
         "Checks if the data is valid"
 
@@ -393,7 +379,6 @@ class PasswordSafe1(base.DataHandler):
         if (len(input) - 56) % 8 != 0:
             raise base.FormatError
 
-
     def export_data(self, entrystore, password):
         "Exports data from an entrystore"
 
@@ -417,7 +402,6 @@ class PasswordSafe1(base.DataHandler):
 
             iter = entrystore.iter_traverse_next(iter)
 
-
         # encrypt data
         rand = Random.new()
         random = rand.read(8)
@@ -429,7 +413,6 @@ class PasswordSafe1(base.DataHandler):
 
         return random + testhash + salt + iv + ciphertext
 
-
     def import_data(self, input, password):
         "Imports data into an entrystore"
 
@@ -451,9 +434,9 @@ class PasswordSafe1(base.DataHandler):
 
         while len(db) > 0:
 
-            dbentry = { "name" : "", "username" : "", "password" : "", "note" : "" }
+            dbentry = {"name": "", "username": "", "password": "", "note": ""}
 
-            for f in ( "name", "password", "note" ):
+            for f in ("name", "password", "note"):
                 flen, ftype = parse_field_header(db[:8])
                 value = db[8:8 + flen]
 
@@ -474,7 +457,6 @@ class PasswordSafe1(base.DataHandler):
         return entrystore
 
 
-
 class PasswordSafe2(base.DataHandler):
     "Data handler for PasswordSafe 2.x data"
 
@@ -483,11 +465,9 @@ class PasswordSafe2(base.DataHandler):
     exporter    = True
     encryption  = True
 
-
     def __init__(self):
         base.DataHandler.__init__(self)
 
-
     def __get_group(self, entrystore, iter):
         "Returns the group path for an iter"
 
@@ -503,11 +483,10 @@ class PasswordSafe2(base.DataHandler):
 
         return ".".join(path)
 
-
     def __setup_group(self, entrystore, groupmap, group):
         "Sets up a group folder, or returns an existing one"
 
-        if group in ( None, "" ):
+        if group in (None, ""):
             return None
 
         if group in groupmap:
@@ -529,7 +508,6 @@ class PasswordSafe2(base.DataHandler):
 
         return iter
 
-
     def check(self, input):
         "Checks if the data is valid"
 
@@ -542,7 +520,6 @@ class PasswordSafe2(base.DataHandler):
         if (len(input) - 56) % 8 != 0:
             raise base.FormatError
 
-
     def export_data(self, entrystore, password):
         "Exports data from an entrystore"
 
@@ -589,7 +566,6 @@ class PasswordSafe2(base.DataHandler):
 
             iter = entrystore.iter_traverse_next(iter)
 
-
         # encrypt data
         rand = Random.new()
         random  = rand.read(8)
@@ -601,7 +577,6 @@ class PasswordSafe2(base.DataHandler):
 
         return random + testhash + salt + iv + ciphertext
 
-
     def import_data(self, input, password):
         "Imports data into an entrystore"
 
@@ -621,7 +596,6 @@ class PasswordSafe2(base.DataHandler):
         db      = decrypt(SHA(password.encode() + salt).digest(), input[56:], iv)
         entrystore  = data.EntryStore()
 
-
         # read magic entry
         for f in "magic", "version", "prefs":
             flen, ftype = parse_field_header(db)
@@ -670,7 +644,7 @@ class PasswordSafe2(base.DataHandler):
                 group = value
 
             elif ftype == FIELDTYPE_END:
-                if group not in ( None, "" ):
+                if group not in (None, ""):
                     parent = self.__setup_group(entrystore, groupmap, group)
 
                 else:
@@ -689,7 +663,6 @@ class PasswordSafe2(base.DataHandler):
         return entrystore
 
 
-
 class MyPasswordSafe(PasswordSafe2):
     "Data handler for MyPasswordSafe data"
 
@@ -699,7 +672,6 @@ class MyPasswordSafe(PasswordSafe2):
     encryption  = True
 
 
-
 class MyPasswordSafeOld(PasswordSafe1):
     "Data handler for old MyPasswordSafe data"
 
@@ -709,7 +681,6 @@ class MyPasswordSafeOld(PasswordSafe1):
     encryption  = True
 
 
-
 class PasswordGorilla(PasswordSafe2):
     "Data handler for Password Gorilla data"
 
@@ -717,4 +688,3 @@ class PasswordGorilla(PasswordSafe2):
     importer    = True
     exporter    = True
     encryption  = True
-
