@@ -32,7 +32,12 @@ from Cryptodome.Protocol.KDF import PBKDF2
 from Cryptodome.Hash import SHA1
 from Cryptodome.Random import get_random_bytes
 
-import os, re, struct, xml.dom.minidom, zlib
+import defusedxml.minidom
+import os
+import re
+import struct
+import zlib
+
 from io import BytesIO
 
 from xml.parsers.expat import ExpatError
@@ -49,11 +54,9 @@ class RevelationXML(base.DataHandler):
     exporter    = True
     encryption  = False
 
-
     def __init__(self):
         base.DataHandler.__init__(self)
 
-
     def __lookup_entry(self, typename):
         "Looks up an entry type based on an identifier"
 
@@ -64,7 +67,6 @@ class RevelationXML(base.DataHandler):
         else:
             raise entry.EntryTypeError
 
-
     def __lookup_field(self, fieldname):
         "Looks up an entry field based on an identifier"
 
@@ -75,7 +77,6 @@ class RevelationXML(base.DataHandler):
         else:
             raise entry.EntryFieldError
 
-
     def __xml_import_node(self, entrystore, node, parent = None):
         "Imports a node into an entrystore"
 
@@ -125,8 +126,7 @@ class RevelationXML(base.DataHandler):
             # update entry with actual data
             entrystore.update_entry(iter, e)
 
-
-        except ( entry.EntryTypeError, entry.EntryFieldError ):
+        except (entry.EntryTypeError, entry.EntryFieldError):
             raise base.DataError
 
         except KeyError:
@@ -135,7 +135,6 @@ class RevelationXML(base.DataHandler):
         except ValueError:
             raise base.DataError
 
-
     def check(self, input):
         "Checks if the data is valid"
 
@@ -162,7 +161,6 @@ class RevelationXML(base.DataHandler):
         if int(match.group(1)) != 1:
             raise base.VersionError
 
-
     def detect(self, input):
         "Checks if this handler can guarantee to handle some data"
 
@@ -170,10 +168,9 @@ class RevelationXML(base.DataHandler):
             self.check(input)
             return True
 
-        except ( base.FormatError, base.VersionError ):
+        except (base.FormatError, base.VersionError):
             return False
 
-
     def export_data(self, entrystore, password = None, parent = None, level = 0):
         "Serializes data into an XML stream"
 
@@ -192,7 +189,7 @@ class RevelationXML(base.DataHandler):
             xml += tabs + " <notes>%s</notes>\n" % util.escape_markup(e.notes)
 
             for field in e.fields:
-                xml += tabs + " <field id=\"%s\">%s</field>\n" % ( field.id, util.escape_markup(field.value) )
+                xml += tabs + " <field id=\"%s\">%s</field>\n" % (field.id, util.escape_markup(field.value))
 
             xml += RevelationXML.export_data(self, entrystore, password, iter, level + 1)
             xml += tabs + "</entry>\n"
@@ -206,26 +203,23 @@ class RevelationXML(base.DataHandler):
 
         return xml
 
-
     def import_data(self, input, password = None):
         "Imports data from a data stream to an entrystore"
 
         RevelationXML.check(self, input)
 
         try:
-            dom = xml.dom.minidom.parseString(input.strip())
+            dom = defusedxml.minidom.parseString(input.strip())
 
         except ExpatError:
             raise base.FormatError
 
-
         if dom.documentElement.nodeName != "revelationdata":
             raise base.FormatError
 
         if "dataversion" not in dom.documentElement.attributes:
             raise base.FormatError
 
-
         entrystore = data.EntryStore()
 
         for node in dom.documentElement.childNodes:
@@ -234,7 +228,6 @@ class RevelationXML(base.DataHandler):
         return entrystore
 
 
-
 class Revelation(RevelationXML):
     "Handler for Revelation data"
 
@@ -243,11 +236,9 @@ class Revelation(RevelationXML):
     exporter    = True
     encryption  = True
 
-
     def __init__(self):
         RevelationXML.__init__(self)
 
-
     def __generate_header(self):
         "Generates a header"
 
@@ -259,7 +250,6 @@ class Revelation(RevelationXML):
 
         return header
 
-
     def __parse_header(self, header):
         "Parses a data header, returns the data version"
 
@@ -280,7 +270,6 @@ class Revelation(RevelationXML):
 
         return ord(match.group(1))
 
-
     def check(self, input):
         "Checks if the data is valid"
 
@@ -295,7 +284,6 @@ class Revelation(RevelationXML):
         if dataversion != 1:
             raise base.VersionError
 
-
     def detect(self, input):
         "Checks if the handler can guarantee to use the data"
 
@@ -303,10 +291,9 @@ class Revelation(RevelationXML):
             self.check(input)
             return True
 
-        except ( base.FormatError, base.VersionError ):
+        except (base.FormatError, base.VersionError):
             return False
 
-
     def export_data(self, entrystore, password):
         "Exports data from an entrystore"
 
@@ -339,7 +326,6 @@ class Revelation(RevelationXML):
 
         return data
 
-
     def import_data(self, input, password):
         "Imports data into an entrystore"
 
@@ -357,11 +343,9 @@ class Revelation(RevelationXML):
         if dataversion != 1:
             raise base.VersionError
 
-
         cipher = AES.new(password.encode("utf8"), AES.MODE_ECB)
         iv = cipher.decrypt(input[12:28])
 
-
         # decrypt the data
         input = input[28:]
 
@@ -371,7 +355,6 @@ class Revelation(RevelationXML):
         cipher = AES.new(password.encode("utf8"), AES.MODE_CBC, iv)
         input = cipher.decrypt(input)
 
-
         # decompress data
         padlen = input[-1]
         for i in input[-padlen:]:
@@ -380,7 +363,6 @@ class Revelation(RevelationXML):
 
         input = zlib.decompress(input[0:-padlen]).decode()
 
-
         # check and import data
         if input.strip()[:5] != "<?xml":
             raise base.PasswordError
@@ -398,15 +380,13 @@ class Revelation2(RevelationXML):
     exporter    = True
     encryption  = True
 
-
     def __init__(self):
         RevelationXML.__init__(self)
 
-
     def __generate_header(self):
         "Generates a header"
 
-        header =  b"rvl\x00"        # magic string
+        header = b"rvl\x00"        # magic string
         header += b"\x02"           # data version
         header += b"\x00"           # separator
         header += b"\x00\x04\x07"   # application version
@@ -414,7 +394,6 @@ class Revelation2(RevelationXML):
 
         return header
 
-
     def __parse_header(self, header):
         "Parses a data header, returns the data version"
 
@@ -435,7 +414,6 @@ class Revelation2(RevelationXML):
 
         return ord(match.group(1))
 
-
     def check(self, input):
         "Checks if the data is valid"
 
@@ -450,7 +428,6 @@ class Revelation2(RevelationXML):
         if dataversion != 2:
             raise base.VersionError
 
-
     def detect(self, input):
         "Checks if the handler can guarantee to use the data"
 
@@ -458,10 +435,9 @@ class Revelation2(RevelationXML):
             self.check(input)
             return True
 
-        except ( base.FormatError, base.VersionError ):
+        except (base.FormatError, base.VersionError):
             return False
 
-
     def export_data(self, entrystore, password):
         "Exports data from an entrystore"
 
@@ -562,7 +538,6 @@ class RevelationLUKS(RevelationXML):
         self.luks_buff = None
         self.current_slot = False
 
-
     def check(self, input):
         "Checks if the data is valid"
 
@@ -582,7 +557,6 @@ class RevelationLUKS(RevelationXML):
 
         l.close()
 
-
     def detect(self, input):
         "Checks if the handler can guarantee to use the data"
 
@@ -590,10 +564,9 @@ class RevelationLUKS(RevelationXML):
             self.check(input)
             return True
 
-        except ( base.FormatError, base.VersionError ):
+        except (base.FormatError, base.VersionError):
             return False
 
-
     def export_data(self, entrystore, password):
         "Exports data from an entrystore"
 
@@ -631,7 +604,6 @@ class RevelationLUKS(RevelationXML):
 
         return buffer.read()
 
-
     def import_data(self, input, password):
         "Imports data into an entrystore"
 
@@ -670,4 +642,3 @@ class RevelationLUKS(RevelationXML):
         entrystore = RevelationXML.import_data(self, data)
 
         return entrystore
-
