@@ -25,10 +25,11 @@
 
 from . import config, datahandler, entry, io, ui, util
 
+import gettext
+import urllib.parse
 import gi
 gi.require_version('Gtk', '3.0')
-from gi.repository import GObject, Gtk, Gio, Gdk
-import gettext, urllib.parse
+from gi.repository import GObject, Gtk, Gio, Gdk  # noqa: E402
 
 _ = gettext.gettext
 
@@ -47,33 +48,29 @@ Gtk.rc_parse_string("""
 """)
 
 
-##### EXCEPTIONS #####
+# EXCEPTIONS #
 
 class CancelError(Exception):
     "Exception for dialog cancellations"
     pass
 
 
-
-##### BASE DIALOGS #####
+# BASE DIALOGS #
 
 class Dialog(Gtk.Dialog):
     "Base class for dialogs"
 
     def __init__(self, parent, title):
-        Gtk.Dialog.__init__(
-            self, title, parent,
-            Gtk.DialogFlags.DESTROY_WITH_PARENT
-        )
+        Gtk.Dialog.__init__(self, title=title)
 
         self.set_border_width(12)
         self.vbox.set_spacing(12)
         self.set_resizable(False)
         self.set_modal(True)
+        self.set_transient_for(parent)
 
         self.connect("key-press-event", self.__cb_keypress)
 
-
     def __cb_keypress(self, widget, data):
         "Callback for handling key presses"
 
@@ -82,7 +79,6 @@ class Dialog(Gtk.Dialog):
             self.response(Gtk.ResponseType.CLOSE)
             return True
 
-
     def run(self):
         "Runs the dialog"
 
@@ -97,7 +93,6 @@ class Dialog(Gtk.Dialog):
             return response
 
 
-
 class Popup(Gtk.Window):
     "Base class for popup (frameless) dialogs"
 
@@ -114,20 +109,17 @@ class Popup(Gtk.Window):
 
         self.connect("key-press-event", self.__cb_keypress)
 
-
     def __cb_keypress(self, widget, data):
         "Callback for key presses"
 
         if data.keyval == Gdk.KEY_Escape:
             self.close()
 
-
     def add(self, widget):
         "Adds a widget to the window"
 
         self.border.add(widget)
 
-
     def close(self):
         "Closes the dialog"
 
@@ -135,7 +127,6 @@ class Popup(Gtk.Window):
         self.emit("closed")
         self.destroy()
 
-
     def realize(self):
         "Realizes the popup and displays children"
 
@@ -144,7 +135,6 @@ class Popup(Gtk.Window):
         for child in self.get_children():
             child.show_all()
 
-
     def show(self, x = None, y = None):
         "Show the dialog"
 
@@ -158,7 +148,6 @@ GObject.signal_new("closed", Popup, GObject.SignalFlags.ACTION,
                    GObject.TYPE_BOOLEAN, ())
 
 
-
 class Utility(Dialog):
     "A utility dialog"
 
@@ -170,7 +159,6 @@ class Utility(Dialog):
 
         self.sizegroup = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
 
-
     def add_section(self, title, description = None):
         "Adds an input section to the dialog"
 
@@ -180,7 +168,6 @@ class Utility(Dialog):
         return section
 
 
-
 class Message(Dialog):
     "A message dialog"
 
@@ -196,7 +183,7 @@ class Message(Dialog):
         # set up image
         if stockimage != None:
             image = ui.Image(stockimage, Gtk.IconSize.DIALOG)
-            image.set_alignment(0.5, 0)
+            image.set_valign(Gtk.Align.START)
             hbox.pack_start(image, False, False, 0)
 
         # set up message
@@ -204,13 +191,12 @@ class Message(Dialog):
         self.contents.set_spacing(10)
         hbox.pack_start(self.contents, True, True, 0)
 
-        label = ui.Label("<span size=\"larger\" weight=\"bold\">%s</span>\n\n%s" % ( util.escape_markup(title), text))
-        label.set_alignment(0, 0)
+        label = ui.Label("<span size=\"larger\" weight=\"bold\">%s</span>\n\n%s" % (util.escape_markup(title), text))
+        label.set_justify(Gtk.Justification.FILL)
         label.set_selectable(True)
         label.set_max_width_chars(45)
         self.contents.pack_start(label, True, True, 0)
 
-
     def run(self):
         "Displays the dialog"
 
@@ -221,7 +207,6 @@ class Message(Dialog):
         return response
 
 
-
 class Error(Message):
     "Displays an error message"
 
@@ -230,7 +215,6 @@ class Error(Message):
         self.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
 
 
-
 class Info(Message):
     "Displays an info message"
 
@@ -239,7 +223,6 @@ class Info(Message):
         self.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
 
 
-
 class Question(Message):
     "Displays a question"
 
@@ -248,7 +231,6 @@ class Question(Message):
         self.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
 
 
-
 class Warning(Message):
     "Displays a warning message"
 
@@ -256,8 +238,7 @@ class Warning(Message):
         Message.__init__(self, parent, title, text, "dialog-warning")
 
 
-
-##### QUESTION DIALOGS #####
+# QUESTION DIALOGS #
 
 class FileChanged(Warning):
     "Notifies about changed file"
@@ -271,7 +252,6 @@ class FileChanged(Warning):
         self.add_button(ui.STOCK_RELOAD, Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.OK)
 
-
     def run(self):
         "Displays the dialog"
 
@@ -293,7 +273,6 @@ class FileChanges(Warning):
         self.add_button(Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.OK)
 
-
     def run(self):
         "Displays the dialog"
 
@@ -305,11 +284,10 @@ class FileChanges(Warning):
         elif response == Gtk.ResponseType.ACCEPT:
             return False
 
-        elif response in ( Gtk.ResponseType.CANCEL, Gtk.ResponseType.CLOSE ):
+        elif response in (Gtk.ResponseType.CANCEL, Gtk.ResponseType.CLOSE):
             raise CancelError
 
 
-
 class FileChangesNew(FileChanges):
     "Asks the user to save changes when creating a new file"
 
@@ -320,7 +298,6 @@ class FileChangesNew(FileChanges):
         )
 
 
-
 class FileChangesOpen(FileChanges):
     "Asks the user to save changes when opening a different file"
 
@@ -331,7 +308,6 @@ class FileChangesOpen(FileChanges):
         )
 
 
-
 class FileChangesQuit(FileChanges):
     "Asks the user to save changes when quitting"
 
@@ -341,6 +317,7 @@ class FileChangesQuit(FileChanges):
             _('You have made changes which have not been saved. If you quit without saving, then these changes will be lost.')
         )
 
+
 class FileChangesClose(FileChanges):
     "Asks the user to save changes when closing"
 
@@ -374,7 +351,6 @@ class FileReplace(Warning):
             raise CancelError
 
 
-
 class FileSaveInsecure(Warning):
     "Asks for confirmation when exporting to insecure file"
 
@@ -388,7 +364,6 @@ class FileSaveInsecure(Warning):
         self.add_button(Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.CANCEL)
 
-
     def run(self):
         "Runs the dialog"
 
@@ -399,8 +374,7 @@ class FileSaveInsecure(Warning):
             raise CancelError
 
 
-
-##### FILE SELECTION DIALOGS #####
+# FILE SELECTION DIALOGS #
 
 class FileSelector(Gtk.FileChooserNative):
     "A normal file selector"
@@ -413,7 +387,6 @@ class FileSelector(Gtk.FileChooserNative):
         self.set_local_only(False)
         self.inputsection = None
 
-
     def add_widget(self, title, widget):
         "Adds a widget to the file selection"
 
@@ -423,7 +396,6 @@ class FileSelector(Gtk.FileChooserNative):
 
         self.inputsection.append_widget(title, widget)
 
-
     def get_filename(self):
         "Returns the file URI"
 
@@ -435,7 +407,6 @@ class FileSelector(Gtk.FileChooserNative):
         else:
             return io.file_normpath(urllib.parse.unquote(uri))
 
-
     def run(self):
         "Displays and runs the file selector, returns the filename"
 
@@ -449,7 +420,6 @@ class FileSelector(Gtk.FileChooserNative):
             raise CancelError
 
 
-
 class ExportFileSelector(FileSelector):
     "A file selector for exporting files"
 
@@ -470,7 +440,6 @@ class ExportFileSelector(FileSelector):
             if self.dropdown.get_item(index)[2] == datahandler.RevelationXML:
                 self.dropdown.set_active(index)
 
-
     def run(self):
         "Displays the dialog"
 
@@ -487,7 +456,6 @@ class ExportFileSelector(FileSelector):
             raise CancelError
 
 
-
 class ImportFileSelector(FileSelector):
     "A file selector for importing files"
 
@@ -506,7 +474,6 @@ class ImportFileSelector(FileSelector):
         for handler in datahandler.get_import_handlers():
             self.dropdown.append_item(handler.name, None, handler)
 
-
     def run(self):
         "Displays the dialog"
 
@@ -523,7 +490,6 @@ class ImportFileSelector(FileSelector):
             raise CancelError
 
 
-
 class OpenFileSelector(FileSelector):
     "A file selector for opening files"
 
@@ -544,7 +510,6 @@ class OpenFileSelector(FileSelector):
         self.add_filter(filter)
 
 
-
 class SaveFileSelector(FileSelector):
     "A file selector for saving files"
 
@@ -567,7 +532,6 @@ class SaveFileSelector(FileSelector):
         self.set_do_overwrite_confirmation(True)
         self.connect("confirm-overwrite", self.__cb_confirm_overwrite)
 
-
     def __cb_confirm_overwrite(self, widget, data = None):
         "Handles confirm-overwrite signals"
 
@@ -581,8 +545,7 @@ class SaveFileSelector(FileSelector):
             return Gtk.FileChooserConfirmation.ACCEPT_FILENAME
 
 
-
-##### PASSWORD DIALOGS #####
+# PASSWORD DIALOGS #
 
 class Password(Message):
     "A base dialog for asking for passwords"
@@ -599,7 +562,6 @@ class Password(Message):
         self.sect_passwords = ui.InputSection()
         self.contents.pack_start(self.sect_passwords, True, True, 0)
 
-
     def add_entry(self, name, entry = None):
         "Adds a password entry to the dialog"
 
@@ -612,7 +574,6 @@ class Password(Message):
 
         return entry
 
-
     def run(self):
         "Displays the dialog"
 
@@ -624,7 +585,6 @@ class Password(Message):
         return Gtk.Dialog.run(self)
 
 
-
 class PasswordChange(Password):
     "A dialog for changing the password"
 
@@ -644,7 +604,6 @@ class PasswordChange(Password):
         self.entry_confirm  = self.add_entry(_('Confirm password'))
         self.entry_confirm.autocheck = False
 
-
     def run(self):
         "Displays the dialog"
 
@@ -672,7 +631,7 @@ class PasswordChange(Password):
                     )
 
                     WarnInsecure.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-                    WarnInsecure.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK )
+                    WarnInsecure.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
                     WarnInsecure.set_default_response(Gtk.ResponseType.CANCEL)
 
                     response = WarnInsecure.run()
@@ -683,7 +642,6 @@ class PasswordChange(Password):
                 return password
 
 
-
 class PasswordLock(Password):
     "Asks for a password when the file is locked"
 
@@ -700,7 +658,6 @@ class PasswordLock(Password):
         self.password = password
         self.entry_password = self.add_entry(_('Password'))
 
-
     def run(self):
         "Displays the dialog"
 
@@ -731,21 +688,19 @@ class PasswordLock(Password):
         self.destroy()
 
 
-
 class PasswordOpen(Password):
     "Password dialog for opening files"
 
     def __init__(self, parent, filename):
         Password.__init__(
             self, parent, _('Enter file password'),
-            _('The file \'%s\' is encrypted. Please enter the file password to open it.') % filename,
+            _('The file “%s” is encrypted. Please enter the file password to open it.') % filename,
             Gtk.STOCK_OPEN
         )
 
         self.set_default_response(Gtk.ResponseType.OK)
         self.entry_password = self.add_entry(_('Password'))
 
-
     def run(self):
         "Displays the dialog"
 
@@ -760,7 +715,6 @@ class PasswordOpen(Password):
             raise CancelError
 
 
-
 class PasswordSave(Password):
     "Password dialog for saving data"
 
@@ -775,7 +729,6 @@ class PasswordSave(Password):
         self.entry_confirm  = self.add_entry(_('Confirm password'))
         self.entry_confirm.autocheck = False
 
-
     def run(self):
         "Displays the dialog"
 
@@ -805,7 +758,7 @@ class PasswordSave(Password):
                     )
 
                     WarnInsecure.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-                    WarnInsecure.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK )
+                    WarnInsecure.add_button(Gtk.STOCK_OK, Gtk.ResponseType.OK)
                     WarnInsecure.set_default_response(Gtk.ResponseType.CANCEL)
 
                     response = WarnInsecure.run()
@@ -816,8 +769,7 @@ class PasswordSave(Password):
                 return password
 
 
-
-##### ENTRY DIALOGS #####
+# ENTRY DIALOGS #
 
 class EntryEdit(Utility):
     "A dialog for editing entries"
@@ -865,7 +817,6 @@ class EntryEdit(Utility):
         # populate the dialog with data
         self.set_entry(e)
 
-
     def __setup_fieldsect(self, fields):
         "Generates a field section based on a field list"
 
@@ -902,11 +853,9 @@ class EntryEdit(Utility):
 
             self.sect_fields.append_widget(field.name, fieldentry)
 
-
         # show widgets
         self.sect_fields.show_all()
 
-
     def get_entry(self):
         "Generates an entry from the dialog contents"
 
@@ -921,7 +870,6 @@ class EntryEdit(Utility):
 
         return e
 
-
     def run(self):
         "Displays the dialog"
 
@@ -942,7 +890,6 @@ class EntryEdit(Utility):
                 self.destroy()
                 raise CancelError
 
-
     def set_entry(self, e):
         "Sets an entry for the dialog"
 
@@ -956,7 +903,6 @@ class EntryEdit(Utility):
         for field in e.fields:
             self.entry_field[type(field)].set_text(field.value or "")
 
-
     def set_fieldwidget_data(self, fieldtype, userdata):
         "Sets user data for fieldwidget"
 
@@ -966,7 +912,6 @@ class EntryEdit(Utility):
             self.entry_field[entry.UsernameField].set_values(userdata)
 
 
-
 class EntryRemove(Warning):
     "Asks for confirmation when removing entries"
 
@@ -984,14 +929,12 @@ class EntryRemove(Warning):
             title   = _('Really remove account \'%s\'?') % entries[0].name
             text    = _('Please confirm that you wish to remove this account.')
 
-
         Warning.__init__(self, parent, title, text)
 
         self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
         self.add_button(Gtk.STOCK_REMOVE, Gtk.ResponseType.OK)
         self.set_default_response(Gtk.ResponseType.CANCEL)
 
-
     def run(self):
         "Displays the dialog"
 
@@ -1002,7 +945,6 @@ class EntryRemove(Warning):
             raise CancelError
 
 
-
 class FolderEdit(Utility):
     "Dialog for editing a folder"
 
@@ -1031,7 +973,6 @@ class FolderEdit(Utility):
         # populate the dialog with data
         self.set_entry(e)
 
-
     def get_entry(self):
         "Generates an entry from the dialog contents"
 
@@ -1041,7 +982,6 @@ class FolderEdit(Utility):
 
         return e
 
-
     def run(self):
         "Displays the dialog"
 
@@ -1062,7 +1002,6 @@ class FolderEdit(Utility):
                 self.destroy()
                 raise CancelError
 
-
     def set_entry(self, e):
         "Sets an entry for the dialog"
 
@@ -1073,8 +1012,7 @@ class FolderEdit(Utility):
         self.entry_desc.set_text(e.description)
 
 
-
-##### MISCELLANEOUS DIALOGS #####
+# MISCELLANEOUS DIALOGS #
 
 class About(Gtk.AboutDialog):
     "About dialog"
@@ -1094,7 +1032,6 @@ class About(Gtk.AboutDialog):
         self.set_authors(config.AUTHORS)
         self.set_artists(config.ARTISTS)
 
-
     def run(self):
         "Displays the dialog"
 
@@ -1104,7 +1041,6 @@ class About(Gtk.AboutDialog):
         self.destroy()
 
 
-
 class Exception(Error):
     "Displays a traceback for an unhandled exception"
 
@@ -1114,8 +1050,8 @@ class Exception(Error):
             _('An unknown error occured. Please report the text below to the Revelation developers, along with what you were doing that may have caused the error. You may attempt to continue running Revelation, but it may behave unexpectedly.')
         )
 
-        self.add_button(Gtk.STOCK_QUIT, Gtk.ResponseType.CANCEL )
-        self.add_button(ui.STOCK_CONTINUE, Gtk.ResponseType.OK )
+        self.add_button(Gtk.STOCK_QUIT, Gtk.ResponseType.CANCEL)
+        self.add_button(ui.STOCK_CONTINUE, Gtk.ResponseType.OK)
 
         textview = ui.TextView(None, traceback)
         scrolledwindow = ui.ScrolledWindow(textview)
@@ -1123,14 +1059,12 @@ class Exception(Error):
 
         self.contents.pack_start(scrolledwindow, True, True, 0)
 
-
     def run(self):
         "Runs the dialog"
 
         return Error.run(self) == Gtk.ResponseType.OK
 
 
-
 class PasswordChecker(Utility):
     "A password checker dialog"
 
@@ -1159,7 +1093,6 @@ class PasswordChecker(Utility):
 
         self.connect("response", self.__cb_response)
 
-
     def __cb_changed(self, widget, data = None):
         "Callback for entry changes"
 
@@ -1182,13 +1115,11 @@ class PasswordChecker(Utility):
         self.result.set_text(result)
         self.result.set_stock(icon, ui.ICON_SIZE_HEADLINE)
 
-
     def __cb_response(self, widget, response):
         "Callback for response"
 
         self.destroy()
 
-
     def run(self):
         "Displays the dialog"
 
@@ -1200,7 +1131,6 @@ class PasswordChecker(Utility):
         self.entry.grab_focus()
 
 
-
 class PasswordGenerator(Utility):
     "A password generator dialog"
 
@@ -1236,7 +1166,6 @@ class PasswordGenerator(Utility):
 
         self.connect("response", self.__cb_response)
 
-
     def __cb_response(self, widget, response):
         "Callback for dialog responses"
 
@@ -1246,7 +1175,6 @@ class PasswordGenerator(Utility):
         else:
             self.destroy()
 
-
     def run(self):
         "Displays the dialog"
 
@@ -1254,8 +1182,7 @@ class PasswordGenerator(Utility):
         self.get_widget_for_response(Gtk.ResponseType.OK).grab_focus()
 
 
-
-##### FUNCTIONS #####
+# FUNCTIONS #
 
 def create_unique(dialog, *args):
     "Creates a unique dialog"
@@ -1315,4 +1242,3 @@ def unique_exists(dialog):
     "Checks if a unique dialog exists"
 
     return dialog in UNIQUE_DIALOGS and UNIQUE_DIALOGS[dialog] != None
-
