@@ -25,10 +25,11 @@
 
 from . import config, data, dialog, entry, io, util
 
+import gettext
+import time
 import gi
 gi.require_version('Gtk', '3.0')
-from gi.repository import GObject, Gtk, Gdk, Gio, Pango
-import gettext, time
+from gi.repository import GObject, Gtk, Gdk, Gio, Pango  # noqa: E402
 
 _ = gettext.gettext
 
@@ -46,9 +47,9 @@ STOCK_NEW_ENTRY         = _("_Add Entry")              # "revelation-new-entry"
 STOCK_NEW_FOLDER        = _("_Add Folder")             # "revelation-new-folder"
 STOCK_NEXT              = "go-down"                    # "revelation-next"
 STOCK_PASSWORD_CHANGE   = _("_Change")                 # "revelation-password-change"
-STOCK_PASSWORD_CHECK    = "revelation-password-check"
-STOCK_PASSWORD_STRONG   = "security-high"              # "revelation-password-strong"
-STOCK_PASSWORD_WEAK     = "security-low"               # "revelation-password-weak"
+STOCK_PASSWORD_CHECK    = "revelation-password-check"  # nosec
+STOCK_PASSWORD_STRONG   = "security-high"              # nosec "revelation-password-strong"
+STOCK_PASSWORD_WEAK     = "security-low"               # nosec "revelation-password-weak"
 STOCK_PREVIOUS          = "go-up"                      # "revelation-previous"
 STOCK_RELOAD            = _("_Reload")                 # "revelation-reload"
 STOCK_REMOVE            = "revelation-remove"
@@ -65,11 +66,11 @@ STOCK_ENTRY_CRYPTOKEY   = "dialog-password"     # "revelation-account-cryptokey"
 STOCK_ENTRY_DATABASE    = "server-database"     # "revelation-account-database"
 STOCK_ENTRY_DOOR        = "changes-allow"       # "revelation-account-door"
 STOCK_ENTRY_EMAIL       = "emblem-mail"         # "revelation-account-email"
-STOCK_ENTRY_FTP         = "system-file-manager" # "revelation-account-ftp"
+STOCK_ENTRY_FTP         = "system-file-manager"  # "revelation-account-ftp"
 STOCK_ENTRY_GENERIC     = "document-new"        # "revelation-account-generic"
 STOCK_ENTRY_PHONE       = "phone"               # "revelation-account-phone"
 STOCK_ENTRY_SHELL       = "utilities-terminal"  # "revelation-account-shell"
-STOCK_ENTRY_REMOTEDESKTOP = "preferences-desktop-remote-desktop" # "revelation-account-remotedesktop"
+STOCK_ENTRY_REMOTEDESKTOP = "preferences-desktop-remote-desktop"  # "revelation-account-remotedesktop"
 STOCK_ENTRY_WEBSITE     = "web-browser"         # "revelation-account-website"
 
 
@@ -84,58 +85,56 @@ ICON_SIZE_LOGO          = Gtk.IconSize.DND
 ICON_SIZE_TREEVIEW      = Gtk.IconSize.MENU
 
 STOCK_ICONS = (
-    ( STOCK_ENTRY_CREDITCARD,   "contact-new",          ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_CRYPTOKEY,    "dialog-password",      ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_DATABASE,     "package_system",       ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_DOOR,         "changes-allow",        ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_EMAIL,        "emblem-mail",          ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_FTP,          "system-file-manager",  ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_GENERIC,      "document-new",         ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_PHONE,        "phone",                ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_SHELL,        "utilities-terminal",   ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_REMOTEDESKTOP,"preferences-desktop-remote-desktop",( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_WEBSITE,      "web-browser",          ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_FOLDER,       "folder",               ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
-    ( STOCK_ENTRY_FOLDER_OPEN,  "folder-open",          ( ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW )),
+    (STOCK_ENTRY_CREDITCARD,   "contact-new",          (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_CRYPTOKEY,    "dialog-password",      (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_DATABASE,     "package_system",       (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_DOOR,         "changes-allow",        (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_EMAIL,        "emblem-mail",          (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_FTP,          "system-file-manager",  (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_GENERIC,      "document-new",         (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_PHONE,        "phone",                (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_SHELL,        "utilities-terminal",   (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_REMOTEDESKTOP, "preferences-desktop-remote-desktop", (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_WEBSITE,      "web-browser",          (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_FOLDER,       "folder",               (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
+    (STOCK_ENTRY_FOLDER_OPEN,  "folder-open",          (ICON_SIZE_DATAVIEW, ICON_SIZE_DROPDOWN, ICON_SIZE_ENTRY, ICON_SIZE_TREEVIEW)),
 )
 
 STOCK_ITEMS = (
-    ( STOCK_CONTINUE,       _('_Continue'),     "stock_test-mode" ),
-    ( STOCK_DISCARD,        _('_Discard'),      Gtk.STOCK_DELETE ),
-    ( STOCK_EDIT,           _('_Edit'),         Gtk.STOCK_EDIT ),
-    ( STOCK_EXPORT,         _('_Export'),       Gtk.STOCK_EXECUTE ),
-    ( STOCK_FOLDER,         '',                 "stock_folder" ),
-    ( STOCK_GENERATE,       _('_Generate'),     Gtk.STOCK_EXECUTE ),
-    ( STOCK_GOTO,           _('_Go to'),        Gtk.STOCK_JUMP_TO ),
-    ( STOCK_IMPORT,         _('_Import'),       Gtk.STOCK_CONVERT ),
-    ( STOCK_LOCK,           _('_Lock'),         "stock_lock" ),
-    ( STOCK_NEW_ENTRY,      _('_Add Entry'),    Gtk.STOCK_ADD ),
-    ( STOCK_NEW_FOLDER,     _('_Add Folder'),   "stock_folder" ),
-    ( STOCK_NEXT,           _('Next'),          Gtk.STOCK_GO_DOWN ),
-    ( STOCK_PASSWORD_CHANGE,_('_Change'),       "stock_lock-ok" ),
-    ( STOCK_PASSWORD_CHECK, _('_Check'),        "stock_lock-ok" ),
-    ( STOCK_PASSWORD_STRONG,'',                 "stock_lock-ok" ),
-    ( STOCK_PASSWORD_WEAK,  '',                 "stock_lock-broken" ),
-    ( STOCK_PREVIOUS,       _('Previous'),      Gtk.STOCK_GO_UP ),
-    ( STOCK_RELOAD,         _('_Reload'),       Gtk.STOCK_REFRESH ),
-    ( STOCK_REMOVE,         _('Re_move'),       Gtk.STOCK_DELETE ),
-    ( STOCK_REPLACE,        _('_Replace'),      Gtk.STOCK_SAVE_AS ),
-    ( STOCK_UNKNOWN,        _('Unknown'),       "dialog-question" ),
-    ( STOCK_UNLOCK,         _('_Unlock'),       "stock_lock-open" ),
-    ( STOCK_UPDATE,         _('_Update'),       "stock_edit" ),
+    (STOCK_CONTINUE,       _('_Continue'),     "stock_test-mode"),
+    (STOCK_DISCARD,        _('_Discard'),      Gtk.STOCK_DELETE),
+    (STOCK_EDIT,           _('_Edit'),         Gtk.STOCK_EDIT),
+    (STOCK_EXPORT,         _('_Export'),       Gtk.STOCK_EXECUTE),
+    (STOCK_FOLDER,         '',                 "stock_folder"),
+    (STOCK_GENERATE,       _('_Generate'),     Gtk.STOCK_EXECUTE),
+    (STOCK_GOTO,           _('_Go to'),        Gtk.STOCK_JUMP_TO),
+    (STOCK_IMPORT,         _('_Import'),       Gtk.STOCK_CONVERT),
+    (STOCK_LOCK,           _('_Lock'),         "stock_lock"),
+    (STOCK_NEW_ENTRY,      _('_Add Entry'),    Gtk.STOCK_ADD),
+    (STOCK_NEW_FOLDER,     _('_Add Folder'),   "stock_folder"),
+    (STOCK_NEXT,           _('Next'),          Gtk.STOCK_GO_DOWN),
+    (STOCK_PASSWORD_CHANGE, _('_Change'),       "stock_lock-ok"),
+    (STOCK_PASSWORD_CHECK, _('_Check'),        "stock_lock-ok"),
+    (STOCK_PASSWORD_STRONG, '',                 "stock_lock-ok"),
+    (STOCK_PASSWORD_WEAK,  '',                 "stock_lock-broken"),
+    (STOCK_PREVIOUS,       _('Previous'),      Gtk.STOCK_GO_UP),
+    (STOCK_RELOAD,         _('_Reload'),       Gtk.STOCK_REFRESH),
+    (STOCK_REMOVE,         _('Re_move'),       Gtk.STOCK_DELETE),
+    (STOCK_REPLACE,        _('_Replace'),      Gtk.STOCK_SAVE_AS),
+    (STOCK_UNKNOWN,        _('Unknown'),       "dialog-question"),
+    (STOCK_UNLOCK,         _('_Unlock'),       "stock_lock-open"),
+    (STOCK_UPDATE,         _('_Update'),       "stock_edit"),
 )
 
 
-
-##### EXCEPTIONS #####
+# EXCEPTIONS #
 
 class DataError(Exception):
     "Exception for invalid data"
     pass
 
 
-
-##### FUNCTIONS #####
+# FUNCTIONS #
 
 def generate_field_display_widget(field, cfg = None, userdata = None):
     "Generates a widget for displaying a field value"
@@ -179,6 +178,7 @@ def generate_field_edit_widget(field, cfg = None, userdata = None):
 
     return widget
 
+
 def setup_comboboxentry(widget, userdata=None):
     widget.entry = widget.get_child()
     widget.entry.set_activates_default(True)
@@ -210,7 +210,7 @@ def setup_comboboxentry(widget, userdata=None):
         widget.set_values(userdata)
 
 
-##### CONTAINERS #####
+# CONTAINERS #
 
 class HBox(Gtk.HBox):
     "A horizontal container"
@@ -225,7 +225,6 @@ class HBox(Gtk.HBox):
             self.pack_start(widget, True, True, 0)
 
 
-
 class HButtonBox(Gtk.HButtonBox):
     "A horizontal button box"
 
@@ -239,7 +238,6 @@ class HButtonBox(Gtk.HButtonBox):
             self.pack_start(button, True, True, 0)
 
 
-
 class VBox(Gtk.VBox):
     "A vertical container"
 
@@ -253,14 +251,12 @@ class VBox(Gtk.VBox):
             self.pack_start(widget, True, True, 0)
 
 
-
 class Notebook(Gtk.Notebook):
     "A notebook (tabbed view)"
 
     def __init__(self):
         Gtk.Notebook.__init__(self)
 
-
     def create_page(self, title):
         "Creates a notebook page"
 
@@ -270,7 +266,6 @@ class Notebook(Gtk.Notebook):
         return page
 
 
-
 class NotebookPage(VBox):
     "A notebook page"
 
@@ -281,7 +276,6 @@ class NotebookPage(VBox):
         self.set_border_width(12)
         self.set_spacing(18)
 
-
     def add_section(self, title, description = None):
         "Adds an input section to the notebook"
 
@@ -291,7 +285,6 @@ class NotebookPage(VBox):
         return section
 
 
-
 class ScrolledWindow(Gtk.ScrolledWindow):
     "A scrolled window for partially displaying a child widget"
 
@@ -304,7 +297,6 @@ class ScrolledWindow(Gtk.ScrolledWindow):
             self.add(contents)
 
 
-
 class Toolbar(Gtk.Toolbar):
     "A Toolbar subclass"
 
@@ -316,7 +308,6 @@ class Toolbar(Gtk.Toolbar):
 
         self.insert(space, -1)
 
-
     def append_widget(self, widget, tooltip = None):
         "Appends a widget to the toolbar"
 
@@ -329,7 +320,6 @@ class Toolbar(Gtk.Toolbar):
         self.insert(toolitem, -1)
 
 
-
 class InputSection(VBox):
     "A section of input fields"
 
@@ -351,7 +341,6 @@ class InputSection(VBox):
         if sizegroup is None:
             self.sizegroup = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
 
-
     def append_widget(self, title, widget, indent = True):
         "Adds a widget to the section"
 
@@ -369,17 +358,15 @@ class InputSection(VBox):
 
         row.pack_start(widget, True, True, 0)
 
-
     def clear(self):
         "Removes all widgets"
 
         for child in self.get_children():
-            if child not in ( self.title, self.desc ):
+            if child not in (self.title, self.desc):
                 child.destroy()
 
 
-
-##### DISPLAY WIDGETS #####
+# DISPLAY WIDGETS #
 
 class EventBox(Gtk.EventBox):
     "A container which handles events for a widget (for tooltips etc)"
@@ -391,7 +378,6 @@ class EventBox(Gtk.EventBox):
             self.add(widget)
 
 
-
 class Image(Gtk.Image):
     "A widget for displaying an image"
 
@@ -402,7 +388,6 @@ class Image(Gtk.Image):
             self.set_from_icon_name(stock, size)
 
 
-
 class ImageLabel(HBox):
     "A label with an image"
 
@@ -421,26 +406,22 @@ class ImageLabel(HBox):
         if stock != None:
             self.set_stock(stock, size)
 
-
     def set_ellipsize(self, ellipsize):
         "Sets label ellisization"
 
         self.label.set_ellipsize(ellipsize)
 
-
     def set_stock(self, stock, size):
         "Sets the image"
 
         self.image.set_from_icon_name(stock, size)
 
-
     def set_text(self, text):
         "Sets the label text"
 
         self.label.set_text(text)
 
 
-
 class Label(Gtk.Label):
     "A text label"
 
@@ -462,7 +443,6 @@ class Label(Gtk.Label):
         elif justify == Gtk.Justification.RIGHT:
             self.set_halign(Gtk.Align.END)
 
-
     def set_text(self, text):
         "Sets the text of the label"
 
@@ -473,11 +453,10 @@ class Label(Gtk.Label):
             Gtk.Label.set_markup(self, text)
 
 
-
 class PasswordLabel(EventBox):
     "A label for displaying passwords"
 
-    def __init__(self, password = "", cfg = None, clipboard = None, justify = Gtk.Justification.LEFT):
+    def __init__(self, password = "", cfg = None, clipboard = None, justify = Gtk.Justification.LEFT):  # nosec
         EventBox.__init__(self)
 
         self.password   = util.unescape_markup(password)
@@ -494,13 +473,11 @@ class PasswordLabel(EventBox):
         self.connect("button-press-event", self.__cb_button_press)
         self.connect("drag-data-get", self.__cb_drag_data_get)
 
-
     def __cb_drag_data_get(self, widget, context, selection, info, timestamp, data = None):
         "Provides data for a drag operation"
 
         selection.set_text(self.password, -1)
 
-
     def __cb_button_press(self, widget, data = None):
         "Populates the popup menu"
 
@@ -519,13 +496,11 @@ class PasswordLabel(EventBox):
 
             return True
 
-
     def set_ellipsize(self, ellipsize):
         "Sets ellipsize for the label"
 
         self.label.set_ellipsize(ellipsize)
 
-
     def show_password(self, show = True):
         "Sets whether to display the password"
 
@@ -551,7 +526,6 @@ class PasswordLabel(EventBox):
             )
 
 
-
 class EditableTextView(Gtk.ScrolledWindow):
     "An editable text view"
 
@@ -580,6 +554,7 @@ class EditableTextView(Gtk.ScrolledWindow):
 
         return self.textbuffer.get_text(self.textbuffer.get_start_iter(), self.textbuffer.get_end_iter(), False)
 
+
 class TextView(Gtk.TextView):
     "A text view"
 
@@ -596,8 +571,7 @@ class TextView(Gtk.TextView):
             self.get_buffer().set_text(text)
 
 
-
-##### TEXT ENTRIES #####
+# TEXT ENTRIES #
 
 class Entry(Gtk.Entry):
     "A normal text entry"
@@ -608,7 +582,6 @@ class Entry(Gtk.Entry):
         self.set_activates_default(True)
         self.set_text(text)
 
-
     def set_text(self, text):
         "Sets the entry contents"
 
@@ -618,7 +591,6 @@ class Entry(Gtk.Entry):
         Gtk.Entry.set_text(self, text)
 
 
-
 class FileEntry(HBox):
     "A file entry"
 
@@ -638,7 +610,6 @@ class FileEntry(HBox):
         if file is not None:
             self.set_filename(file)
 
-
     def __cb_filesel(self, widget, data = None):
         "Displays a file selector when Browse is pressed"
 
@@ -654,26 +625,22 @@ class FileEntry(HBox):
         except dialog.CancelError:
             pass
 
-
     def get_filename(self):
         "Gets the current filename"
 
         return io.file_normpath(self.entry.get_text())
 
-
     def get_text(self):
         "Wrapper to emulate Entry"
 
         return self.entry.get_text()
 
-
     def set_filename(self, filename):
         "Sets the current filename"
 
         self.entry.set_text(io.file_normpath(filename))
         self.entry.set_position(-1)
 
-
     def set_text(self, text):
         "Wrapper to emulate Entry"
 
@@ -685,7 +652,6 @@ GObject.signal_new("changed", FileEntry, GObject.SignalFlags.ACTION,
                    GObject.TYPE_BOOLEAN, ())
 
 
-
 class PasswordEntry(Gtk.Entry):
     "An entry for editing a password (follows the 'show passwords' preference)"
 
@@ -705,7 +671,6 @@ class PasswordEntry(Gtk.Entry):
         if cfg != None:
             self.config.bind('view-passwords', self, "visibility", Gio.SettingsBindFlags.DEFAULT)
 
-
     def __cb_check_password(self, widget, data = None):
         "Callback for changed, checks the password"
 
@@ -715,7 +680,7 @@ class PasswordEntry(Gtk.Entry):
         password = self.get_text()
 
         if len(password) == 0:
-            self.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY,None)
+            self.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, None)
 
         else:
             try:
@@ -727,7 +692,6 @@ class PasswordEntry(Gtk.Entry):
             else:
                 self.set_password_strong(True, _('The password seems good'))
 
-
     def __cb_popup(self, widget, menu):
         "Populates the popup menu"
 
@@ -739,7 +703,6 @@ class PasswordEntry(Gtk.Entry):
 
         menu.show_all()
 
-
     def set_password_strong(self, strong, reason = ""):
         "Sets whether the password is strong or not"
 
@@ -747,7 +710,6 @@ class PasswordEntry(Gtk.Entry):
         self.set_icon_tooltip_text(Gtk.EntryIconPosition.SECONDARY, reason)
 
 
-
 class PasswordEntryGenerate(HBox):
     "A password entry with a generator button"
 
@@ -763,27 +725,23 @@ class PasswordEntryGenerate(HBox):
 
         self.entry = self.pwentry
 
-
     def generate(self):
         "Generates a password for the entry"
 
         password = util.generate_password(self.config.get_int("passwordgen-length"), self.config.get_boolean("passwordgen-punctuation"))
         self.pwentry.set_text(password)
 
-
     def get_text(self):
         "Wrapper for the entry"
 
         return self.pwentry.get_text()
 
-
     def set_text(self, text):
         "Wrapper for the entry"
 
         self.pwentry.set_text(text)
 
 
-
 class SpinEntry(Gtk.SpinButton):
     "An entry for numbers"
 
@@ -796,28 +754,23 @@ class SpinEntry(Gtk.SpinButton):
         self.set_numeric(True)
 
 
-
-##### BUTTONS #####
+# BUTTONS #
 
 class Button(Gtk.Button):
     "A normal button"
 
     def __init__(self, label, callback = None):
-        Gtk.Button.__init__(self, label)
-
-        self.set_use_stock(True)
+        Gtk.Button.__init__(self, label=label)
 
         if callback is not None:
             self.connect("clicked", callback)
 
 
-
 class CheckButton(Gtk.CheckButton):
     "A checkbutton"
 
     def __init__(self, label = None):
-        Gtk.CheckButton.__init__(self, label)
-
+        Gtk.CheckButton.__init__(self, label=label)
 
 
 class DropDown(Gtk.ComboBox):
@@ -841,19 +794,16 @@ class DropDown(Gtk.ComboBox):
 
         self.connect("realize", self.__cb_show)
 
-
     def __cb_show(self, widget, data = None):
         "Callback for when widget is shown"
 
         if self.get_active() == -1:
             self.set_active(0)
 
-
     def append_item(self, text, stock = None, data = None):
         "Appends an item to the dropdown"
 
-        self.model.append( ( text, stock, data ) )
-
+        self.model.append((text, stock, data))
 
     def delete_item(self, index):
         "Removes an item from the dropdown"
@@ -862,31 +812,26 @@ class DropDown(Gtk.ComboBox):
             iter = self.model.iter_nth_child(None, index)
             self.model.remove(iter)
 
-
     def get_active_item(self):
         "Returns a tuple with data for the current item"
 
         iter = self.model.iter_nth_child(None, self.get_active())
         return self.model.get(iter, 0, 1, 2)
 
-
     def get_item(self, index):
         "Returns data for an item"
 
         return self.model.get(self.model.iter_nth_child(None, index), 0, 1, 2)
 
-
     def get_num_items(self):
         "Returns the number of items in the dropdown"
 
         return self.model.iter_n_children(None)
 
-
     def insert_item(self, index, text, stock = None, data = None):
         "Inserts an item in the dropdown"
 
-        self.model.insert(index, ( text, stock, data ) )
-
+        self.model.insert(index, (text, stock, data))
 
 
 class EntryDropDown(DropDown):
@@ -899,7 +844,6 @@ class EntryDropDown(DropDown):
             if e != entry.FolderEntry:
                 self.append_item(e().typename, e().icon, e)
 
-
     def get_active_type(self):
         "Get the currently active type"
 
@@ -908,7 +852,6 @@ class EntryDropDown(DropDown):
         if item is not None:
             return item[2]
 
-
     def set_active_type(self, entrytype):
         "Set the active type"
 
@@ -930,13 +873,11 @@ class FileButton(Gtk.FileChooserButton):
         if file != None:
             self.set_filename(file)
 
-
     def get_filename(self):
         "Gets the filename"
 
         return io.file_normpath(self.get_uri())
 
-
     def set_filename(self, filename):
         "Sets the filename"
 
@@ -950,8 +891,8 @@ class LinkButton(Gtk.LinkButton):
     "A link button"
 
     def __init__(self, url, label):
-        Gtk.LinkButton.__init__(self, url, label)
-        self.set_alignment(0, 0.5)
+        Gtk.LinkButton.__init__(self, uri=url, label=label)
+        self.set_halign(Gtk.Align.START)
 
         self.label = self.get_children()[0]
 
@@ -964,7 +905,6 @@ class LinkButton(Gtk.LinkButton):
 
         self.label.set_ellipsize(ellipsize)
 
-
     def set_justify(self, justify):
         "Sets justify for label"
 
@@ -978,8 +918,7 @@ class RadioButton(Gtk.RadioButton):
         Gtk.RadioButton.__init__(self, group, label)
 
 
-
-##### MENUS AND MENU ITEMS #####
+# MENUS AND MENU ITEMS #
 
 class ImageMenuItem(Gtk.ImageMenuItem):
     "A menuitem with a stock icon"
@@ -993,20 +932,17 @@ class ImageMenuItem(Gtk.ImageMenuItem):
         if text is not None:
             self.set_text(text)
 
-
     def set_stock(self, stock):
         "Set the stock item to use as icon"
 
         self.image.set_from_icon_name(stock, Gtk.IconSize.MENU)
 
-
     def set_text(self, text):
         "Set the item text"
 
         self.label.set_text(text)
 
 
-
 class Menu(Gtk.Menu):
     "A menu"
 
@@ -1014,8 +950,7 @@ class Menu(Gtk.Menu):
         Gtk.Menu.__init__(self)
 
 
-
-##### MISCELLANEOUS WIDGETS #####
+# MISCELLANEOUS WIDGETS #
 
 class TreeView(Gtk.TreeView):
     "A tree display"
@@ -1034,7 +969,6 @@ class TreeView(Gtk.TreeView):
         self.connect("button-press-event", self.__cb_buttonpress)
         self.connect("key-press-event", self.__cb_keypress)
 
-
     def __cb_buttonpress(self, widget, data):
         "Callback for handling mouse clicks"
 
@@ -1062,28 +996,25 @@ class TreeView(Gtk.TreeView):
             return True
 
         # handle drag-and-drop of multiple rows
-        elif self.__cbid_drag_motion is None and data.button in ( 1, 2 ) and data.type == Gdk.EventType.BUTTON_PRESS and path != None and self.selection.iter_is_selected(self.model.get_iter(path[0])) == True and len(self.get_selected()) > 1:
-            self.__cbid_drag_motion = self.connect("motion-notify-event", self.__cb_drag_motion, data.copy() )
-            self.__cbid_drag_end = self.connect("button-release-event", self.__cb_button_release, data.copy() )
+        elif self.__cbid_drag_motion is None and data.button in (1, 2) and data.type == Gdk.EventType.BUTTON_PRESS and path != None and self.selection.iter_is_selected(self.model.get_iter(path[0])) == True and len(self.get_selected()) > 1:
+            self.__cbid_drag_motion = self.connect("motion-notify-event", self.__cb_drag_motion, data.copy())
+            self.__cbid_drag_end = self.connect("button-release-event", self.__cb_button_release, data.copy())
 
             return True
 
-
     def __cb_button_release(self, widget, data, userdata = None):
         "Ends a drag"
 
         self.emit("button-press-event", userdata)
         self.__drag_check_end()
 
-
     def __cb_drag_motion(self, widget, data, userdata = None):
         "Monitors drag motion"
 
         if self.drag_check_threshold(int(userdata.x), int(userdata.y), int(data.x), int(data.y)) == True:
             self.__drag_check_end()
-            uritarget = Gtk.TargetEntry.new( "revelation/treerow", Gtk.TargetFlags.SAME_APP | Gtk.TargetFlags.SAME_WIDGET, 0)
-            self.drag_begin_with_coordinates( Gtk.TargetList([uritarget]), Gdk.DragAction.MOVE, userdata.button.button, userdata, userdata.x, userdata.y)
-
+            uritarget = Gtk.TargetEntry.new("revelation/treerow", Gtk.TargetFlags.SAME_APP | Gtk.TargetFlags.SAME_WIDGET, 0)
+            self.drag_begin_with_coordinates(Gtk.TargetList([uritarget]), Gdk.DragAction.MOVE, userdata.button.button, userdata, userdata.x, userdata.y)
 
     def __cb_keypress(self, widget, data = None):
         "Callback for handling key presses"
@@ -1092,7 +1023,6 @@ class TreeView(Gtk.TreeView):
         if data.keyval == Gdk.KEY_space:
             self.toggle_expanded(self.get_active())
 
-
     def __drag_check_end(self):
         "Ends a drag check"
 
@@ -1102,20 +1032,17 @@ class TreeView(Gtk.TreeView):
         self.__cbid_drag_motion = None
         self.__cbid_drag_end = None
 
-
     def collapse_row(self, iter):
         "Collapse a tree row"
 
         Gtk.TreeView.collapse_row(self, self.model.get_path(iter))
 
-
     def expand_row(self, iter):
         "Expand a tree row"
 
         if iter is not None and self.model.iter_n_children(iter) > 0:
             Gtk.TreeView.expand_row(self, self.model.get_path(iter), False)
 
-
     def expand_to_iter(self, iter):
         "Expand all items up to and including a given iter"
 
@@ -1125,7 +1052,6 @@ class TreeView(Gtk.TreeView):
             iter = self.model.get_iter(path[0:i])
             self.expand_row(iter)
 
-
     def get_active(self):
         "Get the currently active row"
 
@@ -1147,7 +1073,6 @@ class TreeView(Gtk.TreeView):
 
         return list
 
-
     def select(self, iter):
         "Select a particular row"
 
@@ -1158,7 +1083,6 @@ class TreeView(Gtk.TreeView):
             self.expand_to_iter(iter)
             self.set_cursor(self.model.get_path(iter))
 
-
     def select_all(self):
         "Select all rows in the tree"
 
@@ -1166,14 +1090,12 @@ class TreeView(Gtk.TreeView):
         self.selection.emit("changed")
         self.emit("cursor_changed")
 
-
     def set_model(self, model):
         "Change the tree model which is being displayed"
 
         Gtk.TreeView.set_model(self, model)
         self.model = model
 
-
     def toggle_expanded(self, iter):
         "Toggle the expanded state of a row"
 
@@ -1186,7 +1108,6 @@ class TreeView(Gtk.TreeView):
         else:
             self.expand_row(iter)
 
-
     def unselect_all(self):
         "Unselect all rows in the tree"
 
@@ -1202,7 +1123,6 @@ GObject.signal_new("popup", TreeView, GObject.SignalFlags.ACTION,
                    GObject.TYPE_BOOLEAN, (GObject.TYPE_PYOBJECT, ))
 
 
-
 class EntryTree(TreeView):
     "An entry tree"
 
@@ -1225,20 +1145,17 @@ class EntryTree(TreeView):
         self.connect("row-expanded", self.__cb_row_expanded)
         self.connect("row-collapsed", self.__cb_row_collapsed)
 
-
     def __cb_doubleclick(self, widget, iter):
         "Stop doubleclick emission on folder"
 
         if type(self.model.get_entry(iter)) == entry.FolderEntry:
             self.stop_emission("doubleclick")
 
-
     def __cb_row_collapsed(self, object, iter, extra):
         "Updates folder icons when collapsed"
 
         self.model.folder_expanded(iter, False)
 
-
     def __cb_row_expanded(self, object, iter, extra):
         "Updates folder icons when expanded"
 
@@ -1251,7 +1168,6 @@ class EntryTree(TreeView):
 
         self.model.folder_expanded(iter, True)
 
-
     def set_model(self, model):
         "Sets the model displayed by the tree view"
 
@@ -1264,7 +1180,6 @@ class EntryTree(TreeView):
             model.folder_expanded(model.iter_nth_child(None, i), False)
 
 
-
 class Statusbar(Gtk.Statusbar):
     "An application statusbar"
 
@@ -1272,13 +1187,11 @@ class Statusbar(Gtk.Statusbar):
         Gtk.Statusbar.__init__(self)
         self.contextid = self.get_context_id("statusbar")
 
-
     def clear(self):
         "Clears the statusbar"
 
         self.pop(self.contextid)
 
-
     def set_status(self, text):
         "Displays a text in the statusbar"
 
@@ -1286,8 +1199,7 @@ class Statusbar(Gtk.Statusbar):
         self.push(self.contextid, text or "")
 
 
-
-##### ACTION HANDLING #####
+# ACTION HANDLING #
 
 class Action(Gtk.Action):
     "UI Manager Action"
@@ -1299,7 +1211,6 @@ class Action(Gtk.Action):
             self.set_property("is-important", True)
 
 
-
 class ActionGroup(Gtk.ActionGroup):
     "UI Manager Actiongroup"
 
@@ -1313,7 +1224,6 @@ class ActionGroup(Gtk.ActionGroup):
             self.add_action_with_accel(action, accel)
 
 
-
 class ToggleAction(Gtk.ToggleAction):
     "A toggle action item"
 
@@ -1321,7 +1231,6 @@ class ToggleAction(Gtk.ToggleAction):
         Gtk.ToggleAction.__init__(self, name, label, tooltip, stock)
 
 
-
 class UIManager(Gtk.UIManager):
     "UI item manager"
 
@@ -1330,17 +1239,15 @@ class UIManager(Gtk.UIManager):
 
         self.connect("connect-proxy", self.__cb_connect_proxy)
 
-
     def __cb_connect_proxy(self, uimanager, action, widget):
         "Callback for connecting proxies to an action"
 
-        if type(widget) in ( Gtk.MenuItem, Gtk.ImageMenuItem, Gtk.CheckMenuItem ):
+        if type(widget) in (Gtk.MenuItem, Gtk.ImageMenuItem, Gtk.CheckMenuItem):
             widget.tooltip = action.get_property("tooltip")
 
         else:
             widget.set_property("label", widget.get_property("label").replace("...", ""))
 
-
     def add_ui_from_file(self, file):
         "Loads ui from a file"
 
@@ -1350,13 +1257,11 @@ class UIManager(Gtk.UIManager):
         except GObject.GError:
             raise IOError
 
-
     def append_action_group(self, actiongroup):
         "Appends an action group"
 
         Gtk.UIManager.insert_action_group(self, actiongroup, len(self.get_action_groups()))
 
-
     def get_action(self, name):
         "Looks up an action in the managers actiongroups"
 
@@ -1366,7 +1271,6 @@ class UIManager(Gtk.UIManager):
             if action is not None:
                 return action
 
-
     def get_action_group(self, name):
         "Returns the named action group"
 
@@ -1375,8 +1279,7 @@ class UIManager(Gtk.UIManager):
                 return actiongroup
 
 
-
-##### APPLICATION COMPONENTS #####
+# APPLICATION COMPONENTS #
 
 class AppWindow(Gtk.ApplicationWindow):
     "An application window"
@@ -1384,6 +1287,7 @@ class AppWindow(Gtk.ApplicationWindow):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
+
 class App(Gtk.Application):
     "An application"
 
@@ -1393,7 +1297,6 @@ class App(Gtk.Application):
 
         self.toolbars = {}
 
-
     def __connect_menu_statusbar(self, menu):
         "Connects a menus items to the statusbar"
 
@@ -1402,32 +1305,27 @@ class App(Gtk.Application):
                 item.connect("select", self.cb_menudesc, True)
                 item.connect("deselect", self.cb_menudesc, False)
 
-
     def cb_menudesc(self, item, show):
         "Displays menu descriptions in the statusbar"
 
         if show == True:
             self.statusbar.set_status(item.get_label())
 
-
         else:
             self.statusbar.clear()
 
-
     def __cb_toolbar_hide(self, widget, name):
         "Hides the toolbar dock when the toolbar is hidden"
 
         if name in self.toolbars:
             self.toolbars[name].hide()
 
-
     def __cb_toolbar_show(self, widget, name):
         "Shows the toolbar dock when the toolbar is shown"
 
         if name in self.toolbars:
             self.toolbars[name].show()
 
-
     def add_toolbar(self, toolbar, name, band):
         "Adds a toolbar"
 
@@ -1439,7 +1337,6 @@ class App(Gtk.Application):
 
         toolbar.show_all()
 
-
     def get_title(self):
         "Returns the app title"
 
@@ -1447,20 +1344,19 @@ class App(Gtk.Application):
 
         return title.replace(" - " + config.APPNAME, "")
 
-
     def popup(self, menu, button, time):
         "Displays a popup menu"
 
         # get Gtk.Menu
         gmenu = Gtk.Menu.new_from_model(menu)
-        gmenu.attach_to_widget(self.window,None)
+        gmenu.attach_to_widget(self.window, None)
 
         # transfer the tooltips from Gio.Menu to Gtk.Menu
         menu_item_index = 0
-        menu_items=gmenu.get_children()
+        menu_items = gmenu.get_children()
         for sect in range(menu.get_n_items()):
-            for item in range(menu.get_item_link(sect,'section').get_n_items()):
-                tooltip_text = menu.get_item_link(sect,'section').get_item_attribute_value(item,'tooltip',None)
+            for item in range(menu.get_item_link(sect, 'section').get_n_items()):
+                tooltip_text = menu.get_item_link(sect, 'section').get_item_attribute_value(item, 'tooltip', None)
                 if tooltip_text:
                     tooltip_text = tooltip_text.unpack()
                 menu_items[menu_item_index].set_tooltip_text(tooltip_text)
@@ -1469,8 +1365,7 @@ class App(Gtk.Application):
             menu_item_index += 1
 
         self.__connect_menu_statusbar(gmenu)
-        gmenu.popup(None, None, None, None, button, time)
-
+        gmenu.popup_at_pointer()
 
     def set_menus(self, menubar):
         "Sets the menubar for the application"
@@ -1480,13 +1375,11 @@ class App(Gtk.Application):
 
         self.main_vbox.pack_start(menubar, False, True, 0)
 
-
     def set_title(self, title):
         "Sets the window title"
 
         Gtk.Window.set_title(self.window, title + " - " + config.APPNAME)
 
-
     def set_toolbar(self, toolbar):
         "Sets the application toolbar"
 
@@ -1498,7 +1391,6 @@ class App(Gtk.Application):
         self.main_vbox.pack_start(widget, True, True, 0)
 
 
-
 class EntryView(VBox):
     "A component for displaying an entry"
 
@@ -1511,7 +1403,6 @@ class EntryView(VBox):
         self.clipboard  = clipboard
         self.entry      = None
 
-
     def clear(self, force = False):
         "Clears the data view"
 
@@ -1520,7 +1411,6 @@ class EntryView(VBox):
         for child in self.get_children():
             child.destroy()
 
-
     def display_entry(self, e):
         "Displays info about an entry"
 
@@ -1542,11 +1432,11 @@ class EntryView(VBox):
         label.set_valign(Gtk.Align.CENTER)
         metabox.pack_start(label, True, True, 0)
 
-        label = Label("<span weight=\"bold\">%s</span>%s" % ( e.typename + (e.description != "" and ": " or ""), util.escape_markup(e.description) ), Gtk.Justification.CENTER)
+        label = Label("<span weight=\"bold\">%s</span>%s" % (e.typename + (e.description != "" and ": " or ""), util.escape_markup(e.description)), Gtk.Justification.CENTER)
         metabox.pack_start(label, True, True, 0)
 
         # set up field list
-        fields = [ field for field in e.fields if field.value != "" ]
+        fields = [field for field in e.fields if field.value != ""]
 
         if len(fields) > 0:
             table = Gtk.Grid()
@@ -1565,17 +1455,16 @@ class EntryView(VBox):
 
         # notes
         label = Label("<span weight=\"bold\">%s</span>%s" % ((e.notes != "" and _("Notes: ") or ""),
-            util.escape_markup(e.notes) ), Gtk.Justification.LEFT)
+                                                             util.escape_markup(e.notes)), Gtk.Justification.LEFT)
         self.pack_start(label)
 
         # display updatetime
         if type(e) != entry.FolderEntry:
-            label = Label((_('Updated %s ago') + "\n%s") % ( util.time_period_rough(e.updated, time.time()), time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(e.updated)) ), Gtk.Justification.CENTER)
+            label = Label((_('Updated %s ago') + "\n%s") % (util.time_period_rough(e.updated, time.time()), time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(e.updated))), Gtk.Justification.CENTER)
             self.pack_start(label)
 
         self.show_all()
 
-
     def pack_start(self, widget):
         "Adds a widget to the data view"
 
@@ -1584,7 +1473,6 @@ class EntryView(VBox):
         VBox.pack_start(self, widget, False, False, 0)
 
 
-
 class Searchbar(Toolbar):
     "A toolbar for easy searching"
 
@@ -1620,7 +1508,6 @@ class Searchbar(Toolbar):
         self.button_next.set_sensitive(False)
         self.button_prev.set_sensitive(False)
 
-
     def __cb_entry_changed(self, widget, data = None):
         "Callback for entry changes"
 
@@ -1629,7 +1516,6 @@ class Searchbar(Toolbar):
         self.button_next.set_sensitive(s)
         self.button_prev.set_sensitive(s)
 
-
     def __cb_key_press(self, widget, data = None):
         "Callback for key presses"
 
@@ -1643,10 +1529,8 @@ class Searchbar(Toolbar):
 
             return True
 
-
     def __cb_show(self, widget, data = None):
         "Callback for widget display"
 
         self.entry.select_region(0, -1)
         self.entry.grab_focus()
-
